==> fitment-service-1.0.2-20190222.083908-2-sources.jar: com/bizvane/fitmentservice/models/po/AppletBrandFunctionRelPO.java <==
package com.bizvane.fitmentservice.models.po;

import java.util.Date;

public class AppletBrandFunctionRelPO {
    private Long appletBrandFunctionRelId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long appletFunctionId;

    private String functionLogo;

    private Boolean customerText;

    private Integer choice;

    private Integer sort;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Boolean valid;

    public Long getAppletBrandFunctionRelId() {
        return appletBrandFunctionRelId;
    }

    public void setAppletBrandFunctionRelId(Long appletBrandFunctionRelId) {
        this.appletBrandFunctionRelId = appletBrandFunctionRelId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo == null ? null : functionLogo.trim();
    }

    public Boolean getCustomerText() {
        return customerText;
    }

    public void setCustomerText(Boolean customerText) {
        this.customerText = customerText;
    }

    public Integer getChoice() {
        return choice;
    }

    public void setChoice(Integer choice) {
        this.choice = choice;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}

==> fitment-service-1.0.2-20190806.101703-20-sources.jar: com/bizvane/fitmentservice/models/po/AppletBrandFunctionRelPO.java <==
package com.bizvane.fitmentservice.models.po;

import java.util.Date;

public class AppletBrandFunctionRelPO {
    private Long appletBrandFunctionRelId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long appletFunctionId;

    private String functionLogo;

    private Boolean customerText;

    private Integer choice;

    private Integer sort;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Boolean valid;
    private String customFunctionName;
    private Boolean customerName;

    public Boolean getCustomerName() {
        return customerName;
    }

    public void setCustomerName(Boolean customerName) {
        this.customerName = customerName;
    }

    public String getCustomFunctionName() {
        return customFunctionName;
    }

    public void setCustomFunctionName(String customFunctionName) {
        this.customFunctionName = customFunctionName;
    }

    public Long getAppletBrandFunctionRelId() {
        return appletBrandFunctionRelId;
    }

    public void setAppletBrandFunctionRelId(Long appletBrandFunctionRelId) {
        this.appletBrandFunctionRelId = appletBrandFunctionRelId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo == null ? null : functionLogo.trim();
    }

    public Boolean getCustomerText() {
        return customerText;
    }

    public void setCustomerText(Boolean customerText) {
        this.customerText = customerText;
    }

    public Integer getChoice() {
        return choice;
    }

    public void setChoice(Integer choice) {
        this.choice = choice;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}
